package com.tv.adsdkdemo.video;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.res.Configuration;
import android.content.res.TypedArray;
import android.media.AudioManager;
import android.media.MediaPlayer;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.SeekBar;
import android.widget.TextView;
import android.widget.Toast;
import com.tv.adsdkdemo.R;
import java.io.IOException;
import java.util.Timer;
import java.util.TimerTask;


/**
 * Created by maning on 16/6/14.
 * 播放器
 */
public class MNViderPlayer extends FrameLayout implements View.OnClickListener, SeekBar.OnSeekBarChangeListener,
        SurfaceHolder.Callback, MediaPlayer.OnCompletionListener,
        MediaPlayer.OnPreparedListener, MediaPlayer.OnErrorListener, MediaPlayer.OnBufferingUpdateListener {

    private static final String TAG = "MNViderPlayer";
    private Context context;
    private Activity activity;

    static final Handler myHandler = new Handler(Looper.getMainLooper()) {
    };
    private int progress;
    // SurfaceView的创建比较耗时，要注意
    private SurfaceHolder surfaceHolder;
    private MediaPlayer mediaPlayer;

    //地址
    private String videoPath;
    private int video_position = 0;

    //控件的位置信息
    private float mediaPlayerX;
    private float mediaPlayerY;

    // 计时器
    private Timer timer_video_time;
    private TimerTask task_video_timer;
    private Timer timer_controller;
    private TimerTask task_controller;

    private boolean isFullscreen = false;
    private boolean isPrepare = false;
    private boolean isNeedNetChangeListen = true;
    private boolean isFirstPlay = false;

    //控件
    private RelativeLayout mn_rl_bottom_menu;
    private SurfaceView mn_palyer_surfaceView;
    private ImageView mn_start_or_pause;
    private ImageView mn_forward;

    private TextView mn_tv_time;
    private SeekBar mn_seekBar;
    private RelativeLayout mn_player_rl_progress;
    private LinearLayout mn_player_ll_error;
    private LinearLayout mn_player_ll_net;
    private ProgressWheel mn_player_progressBar;
    private ImageView mn_player_iv_play_center;
    private int width;
    private int height;

    public MNViderPlayer(Context context) {
        this(context, null);
        DisplayMetrics metrics = context.getApplicationContext().getResources().getDisplayMetrics();
        width = metrics.widthPixels;
        height = metrics.heightPixels;
    }

    public MNViderPlayer(Context context, AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public MNViderPlayer(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.context = context;
        activity = (Activity) this.context;
        //自定义属性相关
        initAttrs(context, attrs);
        //其他
        init();
    }

    private void initAttrs(Context context, AttributeSet attrs) {
        //获取自定义属性
        TypedArray typedArray = context.obtainStyledAttributes(attrs, R.styleable.MNViderPlayer);
        //遍历拿到自定义属性
        for (int i = 0; i < typedArray.getIndexCount(); i++) {
            int index = typedArray.getIndex(i);
            if (index == R.styleable.MNViderPlayer_mnFirstNeedPlay) {
                isFirstPlay = typedArray.getBoolean(R.styleable.MNViderPlayer_mnFirstNeedPlay, false);
            }
        }
        //销毁
        typedArray.recycle();
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);

        int screenWidth = PlayerUtils.getScreenWidth(activity);
        int screenHeight = PlayerUtils.getScreenHeight(activity);
        ViewGroup.LayoutParams layoutParams = getLayoutParams();

        //newConfig.orientation获得当前屏幕状态是横向或者竖向
        //Configuration.ORIENTATION_PORTRAIT 表示竖向
        //Configuration.ORIENTATION_LANDSCAPE 表示横屏
        if (newConfig.orientation == Configuration.ORIENTATION_PORTRAIT) {
            activity.getWindow().clearFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN);
            //计算视频的大小16：9
            layoutParams.width = screenWidth;
            layoutParams.height = screenWidth * 9 / 16;

            setX(mediaPlayerX);
            setY(mediaPlayerY);
        }
        if (newConfig.orientation == Configuration.ORIENTATION_LANDSCAPE) {
            activity.getWindow().addFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN);
            layoutParams.width = screenWidth;
            layoutParams.height = screenHeight;

            setX(0);
            setY(0);
        }
        setLayoutParams(layoutParams);
    }

    //初始化
    private void init() {
        View inflate = View.inflate(context, R.layout.mn_player_view, this);
        mn_rl_bottom_menu = (RelativeLayout) inflate.findViewById(R.id.mn_rl_bottom_menu);
        mn_palyer_surfaceView = (SurfaceView) inflate.findViewById(R.id.mn_palyer_surfaceView);
        mn_start_or_pause = (ImageView) inflate.findViewById(R.id.mn_start_or_pause);
        mn_forward = (ImageView) inflate.findViewById(R.id.mn_forward);

        mn_tv_time = (TextView) inflate.findViewById(R.id.mn_tv_time);
        mn_seekBar = (SeekBar) inflate.findViewById(R.id.mn_seekBar);
        mn_player_rl_progress = (RelativeLayout) inflate.findViewById(R.id.mn_player_rl_progress);
        mn_player_ll_error = (LinearLayout) inflate.findViewById(R.id.mn_player_ll_error);
        mn_player_ll_net = (LinearLayout) inflate.findViewById(R.id.mn_player_ll_net);
        mn_player_progressBar = (ProgressWheel) inflate.findViewById(R.id.mn_player_progressBar);
        mn_player_iv_play_center = (ImageView) inflate.findViewById(R.id.mn_player_iv_play_center);

        mn_seekBar.setOnSeekBarChangeListener(this);
        mn_player_ll_error.setOnClickListener(this);
        mn_player_ll_net.setOnClickListener(this);
        mn_player_iv_play_center.setOnClickListener(this);

        //初始化
        initViews();

        if (!isFirstPlay) {
            mn_player_iv_play_center.setVisibility(View.VISIBLE);
            mn_player_progressBar.setVisibility(View.GONE);
        }

        //初始化SurfaceView
        initSurfaceView();

        //存储控件的位置信息
        myHandler.postDelayed(new Runnable() {
            @Override
            public void run() {
                mediaPlayerX = getX();
                mediaPlayerY = getY();
                Log.i(TAG, "控件的位置---X：" + mediaPlayerX + "，Y：" + mediaPlayerY);
            }
        }, 1000);
    }

    private void initViews() {
        mn_rl_bottom_menu.setVisibility(View.GONE);
        mn_player_rl_progress.setVisibility(View.VISIBLE);
        mn_player_progressBar.setVisibility(View.VISIBLE);
        mn_player_ll_error.setVisibility(View.GONE);
        mn_player_ll_net.setVisibility(View.GONE);
        mn_player_iv_play_center.setVisibility(View.GONE);
    }

    private void initSurfaceView() {
        Log.i(TAG, "initSurfaceView");
        // 得到SurfaceView容器，播放的内容就是显示在这个容器里面
        surfaceHolder = mn_palyer_surfaceView.getHolder();
        surfaceHolder.setKeepScreenOn(true);
        // SurfaceView的一个回调方法
        surfaceHolder.addCallback(this);
    }


    @Override
    public void onClick(View v) {
        int i = v.getId();
        if (i == R.id.mn_player_ll_error || i == R.id.mn_player_ll_net || i == R.id.mn_player_iv_play_center) {
            playVideo( );
        }

    }
    //--------------------------------------------------------------------------------------
    // ######## 相关View的操作 ########
    //--------------------------------------------------------------------------------------

    public void startOrPause() {
        if (mediaPlayer != null) {
            if (mediaPlayer.isPlaying()) {
                Log.e("zxh","startOrPause:pause");
                mn_start_or_pause.setImageResource(R.drawable.ic_play);
                mn_start_or_pause.setVisibility(VISIBLE);
                mediaPlayer.pause();
                if (onStartOrPauseListener!=null){
                    onStartOrPauseListener.onPause();
                }
            } else {
                Log.e("zxh","startOrPause:start");
                mediaPlayer.start();
                mn_start_or_pause.setVisibility(INVISIBLE);
                if (onStartOrPauseListener!=null){
                    onStartOrPauseListener.onStart();
                }
            }
        }
    }

    //下面菜单的显示和隐藏
    private void initBottomMenuState() {
        if (mn_rl_bottom_menu.getVisibility() == View.GONE) {
            initControllerTask();
            mn_rl_bottom_menu.setVisibility(View.VISIBLE);
        } else {
            destroyControllerTask(true);
        }
    }

    private void dismissControllerMenu() {
        mn_rl_bottom_menu.setVisibility(View.GONE);
    }

    private void showErrorView() {
        mn_player_iv_play_center.setVisibility(View.GONE);
        mn_player_ll_net.setVisibility(View.GONE);
        mn_player_progressBar.setVisibility(View.GONE);
        mn_player_ll_error.setVisibility(View.VISIBLE);
    }

    private void showNoNetView() {
        mn_player_iv_play_center.setVisibility(View.GONE);
        mn_player_ll_net.setVisibility(View.VISIBLE);
        mn_player_progressBar.setVisibility(View.GONE);
        mn_player_ll_error.setVisibility(View.GONE);
    }

    //--------------------------------------------------------------------------------------
    // ######## 计时器相关操作 ########
    //--------------------------------------------------------------------------------------

    private void initTimeTask() {
        timer_video_time = new Timer();
        task_video_timer = new TimerTask() {
            @Override
            public void run() {
                myHandler.post(new Runnable() {
                    @Override
                    public void run() {
                        if (mediaPlayer == null) {
                            return;
                        }
                        if (mn_forward.getVisibility() != VISIBLE)
                        //设置时间
                        {
                            mn_tv_time.setText(String.valueOf(PlayerUtils.converLongTimeToStr(mediaPlayer.getCurrentPosition()) + " / " + PlayerUtils
                                    .converLongTimeToStr(mediaPlayer.getDuration())));
                            //进度条
                            int progress = mediaPlayer.getCurrentPosition();
                            mn_seekBar.setProgress(progress);
                        }
                    }
                });
            }
        };
        timer_video_time.schedule(task_video_timer, 0, 1000);
    }

    private void destroyTimeTask() {
        if (timer_video_time != null && task_video_timer != null) {
            timer_video_time.cancel();
            task_video_timer.cancel();
            timer_video_time = null;
            task_video_timer = null;
        }
    }

    private void initControllerTask() {
        // 设置计时器,控制器的影藏和显示
        timer_controller = new Timer();
        task_controller = new TimerTask() {
            @Override
            public void run() {
                destroyControllerTask(false);
            }
        };
        timer_controller.schedule(task_controller, 10000000);
        initTimeTask();
    }

    private void destroyControllerTask(boolean isMainThread) {
        if (isMainThread) {
            dismissControllerMenu();
        } else {
            myHandler.post(new Runnable() {
                @Override
                public void run() {
                    dismissControllerMenu();
                }
            });
        }
        if (timer_controller != null && task_controller != null) {
            timer_controller.cancel();
            task_controller.cancel();
            timer_controller = null;
            task_controller = null;
        }
        destroyTimeTask();
    }

    //--------------------------------------------------------------------------------------
    // ######## 接口方法实现 ########
    //--------------------------------------------------------------------------------------
    @Override
    public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
        if (onProgressListener!=null){
            onProgressListener.onProgress(progress/1000);
        }
    }

    @Override
    public void onStartTrackingTouch(SeekBar seekBar) {

    }

    @Override
    public void onStopTrackingTouch(SeekBar seekBar) {
        if (mediaPlayer != null && mediaPlayer.isPlaying()) {
            int maxCanSeekTo = seekBar.getMax() - 5 * 1000;
            if (seekBar.getProgress() < maxCanSeekTo) {
                mediaPlayer.seekTo(seekBar.getProgress());
            } else {
                //不能拖到最后
                mediaPlayer.seekTo(maxCanSeekTo);
            }
        }
    }

    //播放
    @Override
    public void surfaceCreated(SurfaceHolder holder) {
        Log.i(TAG, "surfaceCreated");
        mediaPlayer = new MediaPlayer();
        mediaPlayer.setAudioStreamType(AudioManager.STREAM_MUSIC);
        mediaPlayer.setDisplay(holder); // 添加到容器中
        //播放完成的监听
        mediaPlayer.setOnCompletionListener(this);
        // 异步准备的一个监听函数，准备好了就调用里面的方法
        mediaPlayer.setOnPreparedListener(this);
        //播放错误的监听
        mediaPlayer.setOnErrorListener(this);
        mediaPlayer.setOnBufferingUpdateListener(this);
        //第一次初始化需不需要主动播放
        if (isFirstPlay) {
            //判断当前有没有网络（播放的是网络视频）
            if (!PlayerUtils.isNetworkConnected(context) && videoPath.startsWith("http")) {
                Toast.makeText(context, context.getString(R.string.mnPlayerNoNetHint), Toast.LENGTH_SHORT).show();
                showNoNetView();
            } else {
                //手机网络给提醒
                if (PlayerUtils.isMobileConnected(context)) {
                    Toast.makeText(context, context.getString(R.string.mnPlayerMobileNetHint), Toast.LENGTH_SHORT).show();
                }
                //添加播放路径
                try {
                    mediaPlayer.setDataSource(videoPath);
                    // 准备开始,异步准备，自动在子线程中
                    mediaPlayer.prepareAsync();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        isFirstPlay = true;
    }

    @Override
    public void surfaceChanged(SurfaceHolder holder, int format, int width, int height) {
    }

    @Override
    public void surfaceDestroyed(SurfaceHolder holder) {
        //保存播放位置
        if (mediaPlayer != null) {
            video_position = mediaPlayer.getCurrentPosition();
        }
        destroyControllerTask(true);
        pauseVideo();
        Log.i(TAG, "surfaceDestroyed---video_position：" + video_position);
    }

    //MediaPlayer
    @Override
    public void onCompletion(MediaPlayer mediaPlayer) {
        destroyControllerTask(true);
        video_position = 0;
        if (onCompletionListener != null) {
            onCompletionListener.onCompletion(mediaPlayer);
        }
    }

    @Override
    public void onBufferingUpdate(MediaPlayer mp, int percent) {
        Log.i(TAG, "二级缓存onBufferingUpdate: " + percent);
        if (percent >= 0 && percent <= 100) {
            int secondProgress = mp.getDuration() * percent / 100;
            mn_seekBar.setSecondaryProgress(secondProgress);
        }
    }

    @Override
    public boolean onError(MediaPlayer mp, int what, int extra) {
        Log.i(TAG, "发生错误error:" + what);
        if (what != -38) {  //这个错误不管
            showErrorView();
        }
        return true;
    }

    @Override
    public void onPrepared(final MediaPlayer mediaPlayer) {
        mediaPlayer.start(); // 开始播放
        isPrepare = true;
        if (video_position > 0) {
            Log.i(TAG, "onPrepared---video_position:" + video_position);
            mediaPlayer.seekTo(video_position);
            video_position = 0;
        }
        // 把得到的总长度和进度条的匹配
        mn_seekBar.setMax(mediaPlayer.getDuration());
        mn_tv_time.setText(String.valueOf(PlayerUtils.converLongTimeToStr(mediaPlayer.getCurrentPosition()) + "/" + PlayerUtils
                .converLongTimeToStr(mediaPlayer.getDuration())));
        //延时：避免出现上一个视频的画面闪屏
        myHandler.postDelayed(new Runnable() {
            @Override
            public void run() {
                initBottomMenuState();
                mn_player_rl_progress.setVisibility(View.GONE);
            }
        }, 500);
    }


    //--------------------------------------------------------------------------------------
    // ######## 对外提供的方法 ########
    //--------------------------------------------------------------------------------------k
    public void seekTo() {
        mn_forward.setVisibility(INVISIBLE);
        mediaPlayer.seekTo(progress);
        if (!mediaPlayer.isPlaying()) {
            mediaPlayer.start();
        }
    }

    /**
     *
     */
    public void forward() {
        if (mn_forward.getVisibility() != VISIBLE) {
            progress = mediaPlayer.getCurrentPosition();
        }
        mn_forward.setVisibility(VISIBLE);
        mn_start_or_pause.setVisibility(INVISIBLE);

        mn_forward.setBackgroundResource(R.drawable.ic_forward);
        if (mediaPlayer.getCurrentPosition() < mediaPlayer.getDuration() - 5 * 1000) {// 避免超过总时长
            progress += 3000;
            // 把当前位置赋值给进度条
            mn_seekBar.setProgress(progress);
        }
        mn_tv_time.setText(String.valueOf(PlayerUtils.converLongTimeToStr(progress) + " / " + PlayerUtils
                .converLongTimeToStr(mediaPlayer.getDuration())));

    }

    /**
     *
     */
    public void backward() {
        if (mn_forward.getVisibility() != VISIBLE) {
            progress = mediaPlayer.getCurrentPosition();
        }
        mn_start_or_pause.setVisibility(INVISIBLE);
        mn_forward.setVisibility(VISIBLE);
        mn_forward.setBackgroundResource(R.drawable.ic_backward);

        if (progress > 3 * 1000) {// 避免为负
            progress -= 3000;
            mn_seekBar.setProgress(progress);
        } else {
            //什么都不做
            progress = 0;
        }
        mn_tv_time.setText(String.valueOf(PlayerUtils.converLongTimeToStr(progress) + " / " + PlayerUtils
                .converLongTimeToStr(mediaPlayer.getDuration())));

    }

    /**
     * 设置视频信息
     *
     * @param url 视频地址
     */
    public void setDataSource(String url) {
        //地址判空处理
        if (TextUtils.isEmpty(url)) {
            Toast.makeText(context, context.getString(R.string.mnPlayerUrlEmptyHint), Toast.LENGTH_SHORT).show();
            return;
        }
        //赋值
        videoPath = url;
    }

    /**
     * 播放视频
     *
     * */
    public void playVideo() {
        playVideo( video_position);
    }

    /**
     * 播放视频（支持上次播放位置）
     * 自己记录上一次播放的位置，然后传递position进来就可以了
     *
     * @param position 视频跳转的位置
     */
    public void playVideo(int position) {

        //销毁ControllerView
        destroyControllerTask(true);

        video_position = position;
        isPrepare = false;

        //判断当前有没有网络（播放的是网络视频）
        if (!PlayerUtils.isNetworkConnected(context) && videoPath.startsWith("http")) {
            Toast.makeText(context, context.getString(R.string.mnPlayerNoNetHint), Toast.LENGTH_SHORT).show();
            showNoNetView();
            return;
        }
        //手机网络给提醒
        if (PlayerUtils.isMobileConnected(context)) {
            Toast.makeText(context, context.getString(R.string.mnPlayerMobileNetHint), Toast.LENGTH_SHORT).show();
        }

        //重置MediaPlayer
        resetMediaPlayer();

        //初始化View
        initViews();
        //判断广播相关
        //网络监听的广播
        if (isNeedNetChangeListen) {
            registerNetReceiver();
        } else {
            unregisterNetReceiver();
        }
    }

    private void resetMediaPlayer() {
        try {
            if (mediaPlayer != null) {
                if (mediaPlayer.isPlaying()) {
                    mediaPlayer.pause();
                    mediaPlayer.stop();
                }
                //重置mediaPlayer
                mediaPlayer.reset();
                //添加播放路径
                mediaPlayer.setDataSource(videoPath);
                // 准备开始,异步准备，自动在子线程中
                mediaPlayer.prepareAsync();
            } else {
                Toast.makeText(context, "播放器初始化失败", Toast.LENGTH_SHORT).show();
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 播放视频
     */
    public void startVideo() {
        if (mediaPlayer != null) {
            mediaPlayer.start();
            mn_start_or_pause.setVisibility(INVISIBLE);
        }
    }

    /**
     * 暂停视频
     */
    public void pauseVideo() {
        if (mediaPlayer != null) {
            mediaPlayer.pause();
            mn_start_or_pause.setImageResource(R.drawable.ic_play);
            mn_start_or_pause.setVisibility(VISIBLE);
            video_position = mediaPlayer.getCurrentPosition();
        }
    }

    /**
     * 设置是否需要网络变化监听
     */
    public void setIsNeedNetChangeListen(boolean isNeedNetChangeListen) {
        this.isNeedNetChangeListen = isNeedNetChangeListen;
    }

    /**
     * 判断是不是全屏状态
     */
    public boolean isFullScreen() {

        if (this.getWidth() == width && this.getHeight() == height) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * 获取当前播放的位置
     */
    public int getVideoCurrentPosition() {
        int position = 0;
        if (mediaPlayer != null) {
            position = mediaPlayer.getCurrentPosition();
        }
        return position;
    }

    /**
     * 获取视频总长度
     */
    public int getVideoTotalDuration() {
        int position = 0;
        if (mediaPlayer != null) {
            position = mediaPlayer.getDuration();
        }
        return position;
    }

    /**
     * 获取管理者
     */
    public MediaPlayer getMediaPlayer() {
        return mediaPlayer;
    }

    /**
     * 销毁资源
     */
    public void destroyVideo() {
        if (mediaPlayer != null) {
            mediaPlayer.stop();
            mediaPlayer.release();// 释放资源
            mediaPlayer = null;
        }
        surfaceHolder = null;
        mn_palyer_surfaceView = null;
        video_position = 0;
        unregisterNetReceiver();
        removeAllListener();
        destroyTimeTask();
        myHandler.removeCallbacksAndMessages(null);
    }

    //--------------------------------------------------------------------------------------
    // ######## 广播相关 ########
    //--------------------------------------------------------------------------------------


    //-------------------------网络变化监听
    public class NetChangeReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {
            if (onNetChangeListener == null || !isNeedNetChangeListen) {
                return;
            }
            ConnectivityManager connectivityManager = (ConnectivityManager) context.getSystemService(Context.CONNECTIVITY_SERVICE);
            NetworkInfo netInfo = connectivityManager.getActiveNetworkInfo();
            if (netInfo != null && netInfo.isAvailable()) {
                if (netInfo.getType() == ConnectivityManager.TYPE_WIFI) { //WiFi网络
                    onNetChangeListener.onWifi(mediaPlayer);
                } else if (netInfo.getType() == ConnectivityManager.TYPE_MOBILE) {   //3g网络
                    onNetChangeListener.onMobile(mediaPlayer);
                } else {    //其他
                    Log.i(TAG, "其他网络");
                }
            } else {
                onNetChangeListener.onNoAvailable(mediaPlayer);
            }
        }
    }

    private NetChangeReceiver netChangeReceiver;

    private void registerNetReceiver() {
        if (netChangeReceiver == null) {
            IntentFilter filter = new IntentFilter(ConnectivityManager.CONNECTIVITY_ACTION);
            netChangeReceiver = new NetChangeReceiver();
            context.registerReceiver(netChangeReceiver, filter);
        }
    }

    private void unregisterNetReceiver() {
        if (netChangeReceiver != null) {
            context.unregisterReceiver(netChangeReceiver);
        }
    }

    //--------------------------------------------------------------------------------------
    // ######## 自定义回调 ########
    //--------------------------------------------------------------------------------------

    private void removeAllListener() {
        if (onNetChangeListener != null) {
            onNetChangeListener = null;
        }
        if (onPlayerCreatedListener != null) {
            onPlayerCreatedListener = null;
        }
    }


    //网络监听回调
    private OnNetChangeListener onNetChangeListener;

    public void setOnNetChangeListener(OnNetChangeListener onNetChangeListener) {
        this.onNetChangeListener = onNetChangeListener;
    }

    public interface OnNetChangeListener {

        //wifi
        void onWifi(MediaPlayer mediaPlayer);

        //手机
        void onMobile(MediaPlayer mediaPlayer);

        //不可用
        void onNoAvailable(MediaPlayer mediaPlayer);
    }

    //SurfaceView初始化完成回调
    private OnPlayerCreatedListener onPlayerCreatedListener;

    public void setOnPlayerCreatedListener(OnPlayerCreatedListener onPlayerCreatedListener) {
        this.onPlayerCreatedListener = onPlayerCreatedListener;
    }

    public interface OnPlayerCreatedListener {

        //不可用
        void onPlayerCreated(String url, String title);
    }

    //-----------------------播放完回调
    private OnCompletionListener onCompletionListener;

    public void setOnCompletionListener(OnCompletionListener onCompletionListener) {
        this.onCompletionListener = onCompletionListener;
    }

    public interface OnCompletionListener {

        void onCompletion(MediaPlayer mediaPlayer);
    }
    //-----------------------播放进度回调
    private OnProgressListener onProgressListener;

    public void setOnProgressListener(OnProgressListener onProgressListener) {
        this.onProgressListener = onProgressListener;
    }

    public interface OnProgressListener {

        void onProgress(int seconds);
    }
    //-----------------------播放进度回调
    private OnStartOrPauseListener onStartOrPauseListener;

    public void setOnStartOrPauseListener(OnStartOrPauseListener onStartOrPauseListener) {
        this.onStartOrPauseListener = onStartOrPauseListener;
    }

    public interface OnStartOrPauseListener {

        void onStart();
        void onPause();
    }
}